@@ -1,23 +1,10 @@
 /*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2002 Joseph Wenninger <jowenn@kde.org>
-    Copyright (C) 2007 Mirko Stocker <me@misto.ch>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __kate_configdialog_h__
@@ -35,17 +22,14 @@
 #include <KUserFeedback/FeedbackConfigWidget>
 #endif
 
+#include "ui_sessionconfigwidget.h"
+
 class QCheckBox;
 class QComboBox;
 class QSpinBox;
 class KateMainWindow;
 class KPluralHandlingSpinBox;
 
-namespace Ui
-{
-class SessionConfigWidget;
-}
-
 struct PluginPageListItem {
     KTextEditor::Plugin *plugin;
     int idInPlugin;
@@ -59,8 +43,7 @@ class KateConfigDialog : public KPageDialog
     Q_OBJECT
 
 public:
-    KateConfigDialog(KateMainWindow *parent, KTextEditor::View *view);
-    ~KateConfigDialog() override;
+    KateConfigDialog(KateMainWindow *parent);
 
 public: // static
     /**
@@ -79,33 +62,33 @@ protected Q_SLOTS:
     void slotChanged();
     void slotHelp();
 
-    void slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetItem *before);
-
 protected:
     void closeEvent(QCloseEvent *event) override;
 
 private:
-    KateMainWindow *m_mainWindow;
+    void addBehaviorPage();
+    void addSessionPage();
+    void addPluginsPage();
+    void addFeedbackPage();
+    void addPluginPages();
+    void addEditorPages();
+
+private:
+    KateMainWindow * const m_mainWindow;
 
-    KTextEditor::View *m_view;
     bool m_dataChanged = false;
 
     QCheckBox *m_modNotifications;
-    QCheckBox *m_modCloseAfterLast;
-    QCheckBox *m_saveMetaInfos;
-    KPluralHandlingSpinBox *m_daysMetaInfos;
     QComboBox *m_cmbQuickOpenMatchMode;
     QComboBox *m_cmbQuickOpenListMode;
+    QSpinBox *m_tabLimit;
+    QCheckBox *m_showTabCloseButton;
+    QCheckBox *m_expandTabs;
 
-    // Sessions Page
-    Ui::SessionConfigWidget *sessionConfigUi;
+    Ui::SessionConfigWidget sessionConfigUi;
 
     QHash<KPageWidgetItem *, PluginPageListItem *> m_pluginPages;
     QList<KTextEditor::ConfigPage *> m_editorPages;
-    KPageWidgetItem *m_applicationPage;
-    KPageWidgetItem *m_editorPage;
-
-    void addEditorPages();
 
 #ifdef WITH_KUSERFEEDBACK
     KUserFeedback::FeedbackConfigWidget *m_userFeedbackWidget = nullptr;
