@@ -1,21 +1,9 @@
 /*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-    Copyright (C) 2014 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2014 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2020 Christoph Cullmann <cullmann@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KATE_TAB_BAR_H
@@ -24,6 +12,8 @@
 #include <QTabBar>
 #include <QUrl>
 
+#include <unordered_map>
+
 namespace KTextEditor
 {
 class Document;
@@ -43,7 +33,12 @@ class KateTabBar : public QTabBar
 
 public:
     explicit KateTabBar(QWidget *parent = nullptr);
-    int insertTab(int idx, KTextEditor::Document *doc);
+
+    /**
+     * Read and apply tab limit as configured
+     */
+    void readConfig();
+
     void tabInserted(int idx) override;
 
     /**
@@ -63,27 +58,13 @@ public:
      */
     bool containsTab(int index) const;
 
-    /**
-     * Sets the URL of the tab with ID \a id to \a url.
-     * \see tabUrl()
-     * \since 17.08
-     */
-    void setTabUrl(int index, const QUrl &url);
-
-    /**
-     * Returns the text of the tab with ID \a id. If the button id does not
-     * exist \a QString() is returned.
-     * \see setTabUrl()
-     * \since 17.08
-     */
-    QUrl tabUrl(int index);
-
     QVariant ensureValidTabData(int idx);
 
     void setCurrentDocument(KTextEditor::Document *doc);
     int documentIdx(KTextEditor::Document *doc);
     void setTabDocument(int idx, KTextEditor::Document *doc);
     KTextEditor::Document *tabDocument(int idx);
+    void removeDocument(KTextEditor::Document *doc);
 
     /**
      * Marks this tabbar as active. That is, current-tab indicators are
@@ -148,6 +129,24 @@ private:
 
     bool m_isActive = false;
     KTextEditor::Document *m_beingAdded = nullptr;
+
+    /**
+     * limit of number of tabs we should keep
+     * default unlimited == 0
+     */
+    int m_tabCountLimit = 0;
+
+    /**
+     * next lru counter value for a tab
+     */
+    quint64 m_lruCounter = 0;
+
+    /**
+     * LRU counter storage, to determine which document has which age
+     * simple 64-bit counter, worst thing that can happen on 64-bit wraparound
+     * is a bit strange tab replacement a few times
+     */
+    std::unordered_map<KTextEditor::Document *, std::pair<quint64, bool>> m_docToLruCounterAndHasTab;
 };
 
 #endif // KATE_TAB_BAR_H
