@@ -1,21 +1,9 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2001, 2005 Anders Lund <anders.lund@lund.tdcadsl.dk>
+   SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+   SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+   SPDX-FileCopyrightText: 2001, 2005 Anders Lund <anders.lund@lund.tdcadsl.dk>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 #include "kateviewspace.h"
 
@@ -217,6 +205,15 @@ void KateViewSpace::removeView(KTextEditor::View *v)
 
     // ...and now: remove from view space
     stack->removeWidget(v);
+
+    // switch to most recently used rather than letting stack choose one
+    // (last element could well be v->document() being removed here)
+    for (auto it = m_registeredDocuments.rbegin(); it != m_registeredDocuments.rend(); ++it) {
+        if (m_docToView.contains(*it)) {
+            showView(*it);
+            break;
+        }
+    }
 }
 
 bool KateViewSpace::showView(KTextEditor::Document *document)
@@ -228,6 +225,18 @@ bool KateViewSpace::showView(KTextEditor::Document *document)
         return false;
     }
 
+    /**
+     * update mru list order
+     */
+    const int index = m_registeredDocuments.lastIndexOf(document);
+    // move view to end of list
+    if (index < 0) {
+        return false;
+    }
+    // move view to end of list
+    m_registeredDocuments.removeAt(index);
+    m_registeredDocuments.append(document);
+
     /**
      * show the wanted view
      */
@@ -242,11 +251,8 @@ bool KateViewSpace::showView(KTextEditor::Document *document)
 
     /**
      * follow current view
-     * we have tabs available for all registered documents!
      */
-    const auto idx = m_tabBar->documentIdx(document);
-    Q_ASSERT(idx != -1);
-    m_tabBar->setCurrentIndex(idx);
+    m_tabBar->setCurrentDocument(document);
 
     // track tab changes again
     connect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
@@ -311,7 +317,7 @@ void KateViewSpace::registerDocument(KTextEditor::Document *doc)
     /**
      * remember our new document
      */
-    m_registeredDocuments.insert(doc);
+    m_registeredDocuments.insert(0, doc);
 
     /**
      * ensure we cleanup after document is deleted, e.g. we remove the tab bar button
@@ -325,14 +331,13 @@ void KateViewSpace::registerDocument(KTextEditor::Document *doc)
     disconnect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
 
     /**
-     * we want a tab for each known document
-     * if we arrive here, there shall be no existing tab!
+     * create the tab for this document, if necessary
      */
-    Q_ASSERT(m_tabBar->documentIdx(doc) == -1);
-    m_tabBar->insertTab(-1, doc);
-
-    updateDocumentState(doc);
+    m_tabBar->setCurrentDocument(doc);
 
+    /**
+     * handle later document state changes
+     */
     connect(doc, &KTextEditor::Document::documentNameChanged, this, &KateViewSpace::updateDocumentName);
     connect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateViewSpace::updateDocumentUrl);
     connect(doc, &KTextEditor::Document::modifiedChanged, this, &KateViewSpace::updateDocumentState);
@@ -351,7 +356,7 @@ void KateViewSpace::documentDestroyed(QObject *doc)
      */
     KTextEditor::Document *invalidDoc = static_cast<KTextEditor::Document *>(doc);
     Q_ASSERT(m_registeredDocuments.contains(invalidDoc));
-    m_registeredDocuments.remove(invalidDoc);
+    m_registeredDocuments.removeAll(invalidDoc);
 
     /**
      * we shall have no views for this document at this point in time!
@@ -362,27 +367,27 @@ void KateViewSpace::documentDestroyed(QObject *doc)
     disconnect(doc, nullptr, this, nullptr);
 
     /**
-     * remove the tab for this document
-     * as we only handle registered documents here, there shall be a tab!
+     * remove the tab for this document, if existing
      */
-    const int idx = m_tabBar->documentIdx(invalidDoc);
-    Q_ASSERT(idx != -1);
-    m_tabBar->removeTab(idx);
+    m_tabBar->removeDocument(invalidDoc);
 }
 
 void KateViewSpace::updateDocumentName(KTextEditor::Document *doc)
 {
+    // update tab button if available, might not be the case for tab limit set!
     const int buttonId = m_tabBar->documentIdx(doc);
-    Q_ASSERT(buttonId >= 0);
-    m_tabBar->setTabText(buttonId, doc->documentName());
-    m_tabBar->setTabToolTip(buttonId, doc->url().toDisplayString());
+    if (buttonId >= 0) {
+        m_tabBar->setTabText(buttonId, doc->documentName());
+    }
 }
 
 void KateViewSpace::updateDocumentUrl(KTextEditor::Document *doc)
 {
+    // update tab button if available, might not be the case for tab limit set!
     const int buttonId = m_tabBar->documentIdx(doc);
-    Q_ASSERT(buttonId >= 0);
-    m_tabBar->setTabUrl(buttonId, doc->url());
+    if (buttonId >= 0) {
+        m_tabBar->setTabToolTip(buttonId, doc->url().toDisplayString());
+    }
 }
 
 void KateViewSpace::updateDocumentState(KTextEditor::Document *doc)
@@ -392,8 +397,11 @@ void KateViewSpace::updateDocumentState(KTextEditor::Document *doc)
         icon = QIcon::fromTheme(QStringLiteral("document-save"));
     }
 
+    // update tab button if available, might not be the case for tab limit set!
     const int buttonId = m_tabBar->documentIdx(doc);
-    m_tabBar->setTabIcon(buttonId, icon);
+    if (buttonId >= 0) {
+        m_tabBar->setTabIcon(buttonId, icon);
+    }
 }
 
 void KateViewSpace::closeTabRequest(int idx)
